@@ -7,13 +7,13 @@
 import sys
 
 # For Http calls
-import httplib, urllib, json, urllib2
+import httplib, urllib, json, urllib2, ssl
 from ntlm import HTTPNtlmAuthHandler
 import MyError
 
 class AGServerHelperNTLM(object):
 
-    def __init__(self, username, password, ags_admin_url, tool=None, basic=False ):
+    def __init__(self, username, password, ags_admin_url, tool=None, basic=False, allowunverifiedssl = False ):
         """Class initialization procedure
 
         Args:
@@ -33,6 +33,16 @@ class AGServerHelperNTLM(object):
         self.Tool = tool
 
         self.ags_admin_url = self.ags_admin_url + '/arcgis/admin'
+        
+        if allowunverifiedssl:
+            try:
+                _create_unverified_https_context = ssl._create_unverified_context
+            except AttributeError:
+                # Legacy Python that doesn't verify HTTPS certificates by default
+                pass
+            else:
+                # Handle target environment that doesn't support HTTPS verification
+                ssl._create_default_https_context = _create_unverified_https_context
 
         passman = urllib2.HTTPPasswordMgrWithDefaultRealm()
         passman.add_password(None, self.ags_admin_url, self.username, self.password)
@@ -311,6 +321,34 @@ class AGServerHelperNTLM(object):
 
         return rezult
 
+    # Check service permission roles
+    def GetRightsGroupsNames(self, folder, service):
+        """Retrieve the service permission role names from service
+
+        Args:
+            self: The reserved object 'self'
+            folder: Service directory
+            service: Name of a service
+
+        Returns: list of strings
+        """
+        # Construct URL to read folder
+        folder = self._processFolderString(folder)
+        manifestURL = "services/" + folder + service + "/permissions?f=json"
+        params = {}
+        statusData = self._requestFromServer(manifestURL, params, method='GET')
+        rezult = list()
+
+        # Check that data returned is not an error object
+        if not self._assertJsonSuccess(statusData):
+            raise MyError.MyError("Error while retrieving permissions information for " + service + ".")
+
+        permissions = json.loads(statusData)
+        for permission in permissions['permissions']:
+            rezult.append(permission['principal'])
+
+        return rezult
+
     # Check service used datasets
     def GetServiceInfo(self, folder):
         """Retrieve the Folder List from the server
